==> testsuite-3.0.19-beta1.tar.gz: testsuite/src/ShellExecService.php <==
<?php

namespace Drupal\testsuite;

/**
 * Test Suite Services.
 */
class ShellExecService extends BaseService {

  /**
   * The root path where all shell_exec commands will run.
   *
   * @var string
   */
  protected $rootPath;

  /**
   * Constructs a new ShellExecService.
   */
  public function __construct() {
    if ($this->hasWebFolder()) {
      $this->rootPath = dirname(dirname(dirname(dirname(dirname(__DIR__)))));
    }
    else {
      $this->rootPath = dirname(dirname(dirname(dirname(__DIR__))));
    }
  }

  /**
   * Gets the initial data from a phpunit statement.
   *
   * @param string $statement
   *   The statement used in Phpunit to call tests from the CMD.
   *
   * @return string
   *   The data pulled with shell_exec.
   */
  public function getData($statement) : string {
    $old_path = getcwd();
    chdir($this->rootPath);
    $results = shell_exec($statement);
    chdir($old_path);
    return $results;
  }

  /**
   * Returns if the Test has errors.
   *
   * @param string $results
   *   The statement used in Phpunit to call tests from the CMDs results.
   *
   * @return bool
   *   Returns if the test returns errors.
   */
  public function ifErrors($results) : bool {
    return preg_match('/ERRORS!/', $results);
  }

  /**
   * Returns the report heading.
   *
   * @param string $results
   *   The statement used in Phpunit to call tests from the CMDs results.
   *
   * @return string
   *   Returns the result.
   */
  public function getReportHeading($results) : string {
    $split_sections = preg_split('/\n|\n\n|\n\n\n/', $results);
    $mainArray = array_filter($split_sections);
    return implode("<br />", $mainArray);
  }

  /**
   * Returns a test result with errors.
   *
   * @param string $module
   *   The module used as an index in the return array.
   * @param string $results
   *   The statement used in Phpunit to call tests from the CMDs results.
   *
   * @return array
   *   Returns the result.
   */
  public function getReportMore($module, $results) : array {
    $classArray = [];
    $split_sections = preg_split('/\n\n\n/', $results);
    $second1_split_sections = preg_split('/\n\n/', $split_sections[0]);
    $section1_split = preg_split('/\n/', $second1_split_sections[1]);
    array_shift($section1_split);
    $classCount = 1;
    for ($i = 0; $i < count($section1_split); $i += 2) {
      if (substr($section1_split[$i], 0, 5) == 'Test ') {
        preg_match_all('/Drupal[^\s]+\s/', $section1_split[$i], $matches);
        $class = str_replace("'", "", $matches[0][0]);
        $class = str_replace(" ", "", $class);
        // dpm($class);
        if (!in_array($class, $classArray)) {
          $classArray[$module][] = [
            'class' => $class,
            'count' => $classCount,
          ];
          $classCountArray[$module][] = $classCount;
          $classCount = 0;
        }
        $classCount++;
      }
    }
    return $classArray;
  }

  /**
   * Returns a test result with errors.
   *
   * @param string $module
   *   The module used as an index in the return array.
   * @param string $results
   *   The statement used in Phpunit to call tests from the CMDs results.
   *
   * @return array
   *   Returns the result.
   */
  public function getErrorArray($module, $results) : array {
    $errorArray = [];
    $split_sections = preg_split('/\n\n\n/', $results);
    $second2_split_sections = preg_split('/\n\n/', $split_sections[1]);
    array_shift($second2_split_sections);
    array_shift($second2_split_sections);
    array_pop($second2_split_sections);
    for ($i = 0; $i < count($second2_split_sections); $i++) {
      $second2_sections = preg_split('/\n/', $second2_split_sections[$i]);
      $errorArray[$module][] = implode("<br />", $second2_sections);
    }
    return $errorArray;
  }

}

==> testsuite-3.0.27-beta1.tar.gz: testsuite/src/ShellExecService.php <==
<?php

namespace Drupal\testsuite;

/**
 * Test Suite Services.
 */
class ShellExecService extends BaseService {

  /**
   * The root path where all shell_exec commands will run.
   *
   * @var string
   */
  protected $rootPath;

  /**
   * Constructs a new ShellExecService.
   */
  public function __construct() {
    if ($this->hasWebFolder()) {
      $this->rootPath = dirname(dirname(dirname(dirname(dirname(__DIR__)))));
    }
    else {
      $this->rootPath = dirname(dirname(dirname(dirname(__DIR__))));
    }
  }

  /**
   * Gets the initial data from a phpunit statement.
   *
   * @param string $statement
   *   The statement used in Phpunit to call tests from the CMD.
   *
   * @return string
   *   The data pulled with shell_exec.
   */
  public function getData($statement) {
    $old_path = getcwd();
    chdir($this->rootPath);
    $results = shell_exec($statement);
    chdir($old_path);
    return $results;
  }

  /**
   * Returns if the Test has errors.
   *
   * @param string $results
   *   The statement used in Phpunit to call tests from the CMDs results.
   *
   * @return bool
   *   Returns if the test returns errors.
   */
  public function ifErrors($results) : bool {
    return preg_match('/ERRORS!/', $results);
  }

  /**
   * Returns the report heading.
   *
   * @param string $results
   *   The statement used in Phpunit to call tests from the CMDs results.
   *
   * @return string
   *   Returns the result.
   */
  public function getReportHeading($results) : string {
    $split_sections = preg_split('/\n|\n\n|\n\n\n/', $results);
    $mainArray = array_filter($split_sections);
    return implode("<br />", $mainArray);
  }

  /**
   * Returns a test result with errors.
   *
   * @param string $module
   *   The module used as an index in the return array.
   * @param string $results
   *   The statement used in Phpunit to call tests from the CMDs results.
   *
   * @return array
   *   Returns the result.
   */
  public function getReportMore($module, $results) : array {
    $classArray = [];
    $split_sections = preg_split('/\n\n\n/', $results);
    $second1_split_sections = preg_split('/\n\n/', $split_sections[0]);
    $section1_split = preg_split('/\n/', $second1_split_sections[1]);
    array_shift($section1_split);
    $classCount = 1;
    for ($i = 0; $i < count($section1_split); $i += 2) {
      if (substr($section1_split[$i], 0, 5) == 'Test ') {
        preg_match_all('/Drupal[^\s]+\s/', $section1_split[$i], $matches);
        $class = str_replace("'", "", $matches[0][0]);
        $class = str_replace(" ", "", $class);
        // dpm($class);
        if (!in_array($class, $classArray)) {
          $classArray[$module][] = [
            'class' => $class,
            'count' => $classCount,
          ];
          $classCountArray[$module][] = $classCount;
          $classCount = 0;
        }
        $classCount++;
      }
    }
    return $classArray;
  }

  /**
   * Returns a test result with errors.
   *
   * @param string $module
   *   The module used as an index in the return array.
   * @param string $results
   *   The statement used in Phpunit to call tests from the CMDs results.
   *
   * @return array
   *   Returns the result.
   */
  public function getErrorArray($module, $results) : array {
    $errorArray = [];
    $split_sections = preg_split('/\n\n\n/', $results);
    $second2_split_sections = preg_split('/\n\n/', $split_sections[1]);
    array_shift($second2_split_sections);
    array_shift($second2_split_sections);
    array_pop($second2_split_sections);
    for ($i = 0; $i < count($second2_split_sections); $i++) {
      $second2_sections = preg_split('/\n/', $second2_split_sections[$i]);
      $errorArray[$module][] = implode(" - ", $second2_sections);
    }
    return $errorArray;
  }

}
